
####################################################################
####################################################################
###################                             ####################
###################      TREE GROWTH PAPER      ####################
###################                             ####################
####################################################################
####################################################################


# Script to compute diversity effects on basal area as standardized effect size (SES) 
# following Potvin and Gotelli (2008)

# initial script downloaded 26/01/2017 from http://www.esapubs.org/archive/ecol/E094/080/suppl-1.php#filelist
# Supporting information for 
#Sapijanskas,J., Potvin, C. and Loreau, M. "Beyond shading: litter production by neighbours contributes to overyielding in tropical trees"
#R code to compute diversity effects as standardized effect size (SES) following Potvin and Gotelli (2008)
#for both (i) plot-level overyielding and (ii) comparison among canopy statuses
#NB: The code could readily be optimized for speed using R inner-built functions 
#(e.g. parLapply() in the package SNOW) but we intentionaly provided 
#a version with explicit loops and subsetting to improve readability for readers
#that are not familiar with R

# modifield by Clara Zemp, 2018


####################################################################################

library(data.table)

rm(list=ls())

# set working directory 
setwd("C:/CRC990-B11/data/trees")

# Get data (basal area) per species and diversity level 
tree.plots = fread("B11.tree.plots.csv")

# get plot information 
#infoplots   <- fread("B11plot_with_controlplots_201705.csv")
#SizePlots = infoplots[,.(S = sum(Size^2)),.(DivLev)] # total plot size (m^2) per diversity level

SizePlots = tree.plots[,.(S = sum(Size^2)),.(DivLev)] # total plot size (m^2) per diversity level

# survival data 
s= fread("B11_survival.divlev.v2.csv")


####################################################################################
## 


# for MORTALITY MODEL - and NET MODEL 
#survival probability  observed in monoculture to feed the binomial model
sA = s[Species=="petai" & DivLev==1]$surv.2015 # survival per diversity level (2, 3 and 6)
sB = s[Species=="Jengkol" & DivLev==1]$surv.2015
sC = s[Species=="durian" & DivLev==1]$surv.2015
sD = s[Species=="jelutung" & DivLev==1]$surv.2015
sE = s[Species=="sungkai" & DivLev==1]$surv.2015
sF = s[Species=="meranti" & DivLev==1]$surv.2015

# for GROWTH MODEL
#survival probability  observed in polyculture to feed the binomial model
# sA = s[Species=="petai" & DivLev>1]$surv.2015 # survival per diversity level (2, 3 and 6)
# sB = s[Species=="Jengkol" & DivLev>1]$surv.2015
# sC = s[Species=="durian" & DivLev>1]$surv.2015
# sD = s[Species=="jelutung" & DivLev>1]$surv.2015
# sE = s[Species=="sungkai" & DivLev>1]$surv.2015
# sF = s[Species=="meranti" & DivLev>1]$surv.2015

Ainit = c(265,176,85) # initial number of individuals planted of species A in multi-species plots per diversity level (2, 3 and 6) 
Binit = c(265,176,85)
Cinit = c(265,176,85)
Dinit = c(265,176,85)
Einit = c(265,176,85)
Finit = c(265,176,85)


####################################################################################
####################################################################################
#(i) Standardized effect size (SES) to detect overyielding
####################################################################################
####################################################################################


#####bootstrap parameters###########################################################
Nrep=1000 # Number of replicate null assemblages

#init vectors and arrays 
dataSES=subset(data, BA.2015>0) 

NullAssemblnetStoc=as.data.frame(matrix(NA,ncol=2,nrow=Nrep))# stores summed basal area of replicate null assemblages
obsBA=rep(NA,3) #3 = 3 diversity levels, 2, 3 or 6 species-mixtures

NStoc=as.data.frame(matrix(NA,ncol=2,nrow=Nrep))# stores number of trees of replicate null assemblages
NObs=rep(NA,3) #3 = 3 diversity levels, 2, 3 or 6 species-mixtures

#do the bootstrapping: 
k=1 #column coding for diversity level (more general block of interest, e.g. plot)
for(divlevel in c(2,3,6)){ #loop on block of interest (here diversity treament)
  
  # CHANGE HERE THE DATE !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
  obsBA[k]=sum(dataSES$BA.2015[dataSES$DivLev==divlevel])#observed summed basal area in diversity level k 
  
  # NObs[k] = length(dataSES2017$BA.2015[dataSES2017$DivLev==divlevel])# observed number of trees at diversity level k (OPTIONAL)
  
  for(i in 1:Nrep){# loop on replicate bootstraps
    
    # for MORTALITY MODEL and NET MODEL
    # stochastic mortality: draw a random number of individuals following species-specific mortality as observed in monocultures
     nAMortStoc=rbinom(1,Ainit[k],sA)
     nBMortStoc=rbinom(1,Binit[k],sB)
     nCMortStoc=rbinom(1,Cinit[k],sC)
     nDMortStoc=rbinom(1,Dinit[k],sD)
     nEMortStoc=rbinom(1,Einit[k],sE)
     nFMortStoc=rbinom(1,Finit[k],sF)
    
    # For GROWTH MODEL 
    # stochastic mortality: draw a random number of individuals following species-specific mortality as observed in POLYCULTURE 
    # nAMortStoc=rbinom(1,Ainit[k],sA[k])
    # nBMortStoc=rbinom(1,Binit[k],sB[k])
    # nCMortStoc=rbinom(1,Cinit[k],sC[k])
    # nDMortStoc=rbinom(1,Dinit[k],sD[k])
    # nEMortStoc=rbinom(1,Einit[k],sE[k])
    # nFMortStoc=rbinom(1,Finit[k],sF[k])
    
    NStoc[i,k]=nAMortStoc+nBMortStoc+nCMortStoc+nDMortStoc+nEMortStoc+nFMortStoc
    
    NullAssemblnetStoc[i,k]=0
    #add the contibution of each species in turn
    if(nAMortStoc>0){ #species A
      
      # CHANGE HERE THE DATE !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
      
      # -- sample nAMortStoc trees from A monocultures and add their summed basal area - for GROWTH MODEL and NET model 
      #temp=subset(dataSES$BA.2015,dataSES$DivLev==1 & dataSES$Species=="petai")
      # -- sample nAMortStoc trees from A POLYCULTURE and add their summed basal area - for MORTALITY MODEL 
      temp=subset(dataSES$BA.2015,dataSES$DivLev==divlevel & dataSES$Species=="petai")
      
      NullAssemblnetStoc[i,k]=NullAssemblnetStoc[i,k]+sum(sample(temp,size=nAMortStoc,replace=TRUE))
    }
    if(nBMortStoc>0){
      
      # CHANGE HERE THE DATE !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
      
      #temp=subset(dataSES$BA.2015,dataSES$DivLev==1 & dataSES$Species=="Jengkol")
      temp=subset(dataSES$BA.2015,dataSES$DivLev==divlevel & dataSES$Species=="Jengkol")
      
      NullAssemblnetStoc[i,k]=NullAssemblnetStoc[i,k]+sum(sample(temp,size=nBMortStoc,replace=TRUE))
    }
    if(nCMortStoc>0){
      
     #temp=subset(dataSES$BA.2015,dataSES$DivLev==1 & dataSES$Species=="durian")
      temp=subset(dataSES$BA.2015,dataSES$DivLev==divlevel & dataSES$Species=="durian")
      NullAssemblnetStoc[i,k]=NullAssemblnetStoc[i,k]+sum(sample(temp,size=nCMortStoc,replace=TRUE))
    }
    if(nDMortStoc>0){
    # temp=subset(dataSES$BA.2015,dataSES$DivLev==1 & dataSES$Species=="jelutung")
      temp=subset(dataSES$BA.2015,dataSES$DivLev==divlevel & dataSES$Species=="jelutung")
      NullAssemblnetStoc[i,k]=NullAssemblnetStoc[i,k]+sum(sample(temp,size=nDMortStoc,replace=TRUE))
    }
    if(nEMortStoc>0){
      #temp=subset(dataSES$BA.2015,dataSES$DivLev==1 & dataSES$Species=="sungkai")
      temp=subset(dataSES$BA.2015,dataSES$DivLev==divlevel & dataSES$Species=="sungkai")
      NullAssemblnetStoc[i,k]=NullAssemblnetStoc[i,k]+sum(sample(temp,size=nEMortStoc,replace=TRUE))
    }
    if(nFMortStoc>0){
    # temp=subset(dataSES$BA.2015,dataSES$DivLev==1 & dataSES$Species=="meranti")
    temp=subset(dataSES$BA.2015,dataSES$DivLev==divlevel & dataSES$Species=="meranti")
      NullAssemblnetStoc[i,k]=NullAssemblnetStoc[i,k]+sum(sample(temp,size=nFMortStoc,replace=TRUE))
    }
    
  }#end loop on bootstrap replicates
  k=k+1
}#end loop on block of interest


scale.to.ha=c(SizePlots[DivLev==2]$S,SizePlots[DivLev==3]$S,SizePlots[DivLev==6]$S)
# scale.to.ha is used to scale diversity-level yields from cm^2 per diversity treatment to yields in m^2 per hectare

# check number of trees (OPTIONAL)
#NObs 
#NMeanStoc = colMeans(NStoc)

# scale to hectare 
ObsBA_scaled = obsBA / scale.to.ha
NullAssemblnetStoc_scaled = as.data.frame(matrix(NA,ncol=3,nrow=Nrep)) #3 = 3 diversity levels, 2, 3 or 6 species-mixtures
for(i in 1:Nrep){
  NullAssemblnetStoc_scaled[i,] = NullAssemblnetStoc[i,] / scale.to.ha
}

MeanNullAssemblnetStoc=colMeans(NullAssemblnetStoc_scaled)
MeanNullAssemblnetStocsd=apply(NullAssemblnetStoc_scaled,2,sd)
MeanNullAssemblnetSES=(ObsBA_scaled - MeanNullAssemblnetStoc) / MeanNullAssemblnetStocsd # SES values

MeanNullAssemblnetSES #should return under- or over-yielding (-2<SES<2) 

# one-sample t-test (for the different level of diversity)
t.test(NullAssemblnetStoc_scaled[,1], mu=ObsBA_scaled[1]) # divlev 2
t.test(NullAssemblnetStoc_scaled[,2], mu=ObsBA_scaled[2]) # divlev 3
t.test(NullAssemblnetStoc_scaled[,3], mu=ObsBA_scaled[3]) # divlev 6


##check normality assumption 
par(mfrow=c(2,1))
apply(NullAssemblnetStoc,2,qqnorm)


