
####################################################################
####################################################################
###################                             ####################
###################      TREE GROWTH PAPER      ####################
###################                             ####################
####################################################################
####################################################################

# script to perform statistical analyses on the tree growth data 
# Written by Clara Zemp, 2019

## multicomparision 
library(data.table)
library(multcomp)
library(sandwich)

## modeling packages
library("lme4")     ## basic (G)LMMs
library("nlme")     ## more LMMs
library("afex")     ## helper functions
library("emmeans")

## graphics
library(ggplot2)   ; theme_set(theme_bw())
library("lattice")
library("dotwhisker")  ## coefficient plots

## data manipulation
library("broom")
library("broom.mixed")

#deleting all objects
rm(list=ls())

# set working directory 
setwd("C:/CRC990-B11/data/trees")


#####################################################################################
# import data 

tr.utm <- fread("tr.utm.csv") # tree distance of oil palm and fence 
tr.nn <- fread('tr.nn.csv') # pairwise distance between trees 

# tree size at individual level 
Size.tree <- fread("B11.tree.merge.csv") # tree diameter, height and survival status  

# tree performance at individual level 
RGR.tree <- fread('RGR.tree.csv') # relative growth rates for each tree invidual
AGR.tree <- fread('AGR.tree.csv') # absolute growth rates for each tree invidual
Mort.tree <- fread('Mort.tree.csv') # mortality rates 

# survival at plot level 
survival.plots <- fread("B11_survival.plots.csv")

# tree competition indices
neighborhood.2015 <- fread("neighborhood_2015.5m.csv")
neighborhood.2016 <- fread("neighborhood_2016.5m.csv")
neighborhood.2017 <- fread("neighborhood_2017.5m.csv")

# tree diversity 
div.2018 <-  fread('div_tree_B11_201801.v2.csv')
div.2017 <-  fread('div_tree_B11_201701.v1.csv')
div.2016 <-  fread('div_tree_B11_201601.v1.csv')
div.2015 <-  fread('div_tree_B11_201501.v1.csv')

# stand strcuture at plot level (optional)
#str.plot <- fread("str.plot.csv")

# plot information 
infoplots   <- fread("C:/CRC990-B11/Experiment/B11plot_with_controlplots_201705.csv") 

# environmental variables 
enviro_B11      <- fread("C:/CRC990-B11/Data/B11_enviro_Teuscher_Gerard_2016.csv")
hemipx_B11      <-fread("C:/CRC990-B11/Data/B11_HemiPix_Anne_2014.csv")
# get plot-average gap fraction from 2014 
hemipx_B11 <- hemipx_B11[,.(openness=mean(Openness_rel)),
                     ,.(Plot)]
# replace in the file 
enviro_B11$gap <- hemipx_B11$openness
  
# # get diversity catergory (mono-species or multi-species plots) 
infoplots$Div <- NA
infoplots[DivLev==1]$Div <- FALSE
infoplots[DivLev>1]$Div <- TRUE

# get species list and total nb of trees 
tree_sp = unique(RGR.tree$Species)
Ntot = length(RGR.tree$TreeID)

# convert to factor or numeric
RGR.tree$Species <- as.factor(RGR.tree$Species)
survival.plots$Species <- as.factor(survival.plots$Species) 

infoplots$Size.fac <- as.factor(infoplots$Size)
infoplots$DivLev <- as.numeric(infoplots$DivLev)
infoplots$DivLev.fac <- as.factor(infoplots$DivLev)
#infoplots$Div <- as.numeric(infoplots$Div)
infoplots$Div <- as.factor(infoplots$Div)

div.2018$R.fac <- as.factor(div.2018$R)
div.2017$R.fac <- as.factor(div.2017$R)
div.2016$R.fac <- as.factor(div.2016$R)
div.2015$R.fac <- as.factor(div.2015$R)

neighborhood.2015$R_neighbors.fac <- as.factor(neighborhood.2015$R_neighbors)
neighborhood.2016$R_neighbors.fac <- as.factor(neighborhood.2016$R_neighbors)
neighborhood.2017$R_neighbors.fac <- as.factor(neighborhood.2017$R_neighbors)

#######################################################################
# clean the data 

#keeps <- c("TreeID","petai","meranti","durian","jelutung","Jengkol","sungkai",
#           "all","consp","heterosp","R_neighbors","Npetai", "Nmeranti","Ndurian","Njelutung","NJengkol","Nsungkai")

#neighborhood.2015 =  subset(neighborhood.2015, select = keeps)
#neighborhood.2016 =  subset(neighborhood.2016, select = keeps)
#neighborhood.2017 =  subset(neighborhood.2017, select = keeps)

keeps <- c("Tree_ID","dOPrem","dEdge","dOPal")
tr.utm= subset(tr.utm, select = keeps)

#######################################################################
# merge data 

## for analysis of plot-specific variables  ###################

B11plots = merge (enviro_B11, infoplots)
#B11plots = merge (B11plots, str.plot)

# merge plot-level enviro variables and mortality 
survival.plots = merge(survival.plots,B11plots,by="PlotID")
survival.plots <- transform(survival.plots,surv.2018 = round(surv.2018*100))
survival.plots <- transform(survival.plots,surv.2017 = round(surv.2017*100))
survival.plots <- transform(survival.plots,surv.2016 = round(surv.2016*100))

# merge plot-level enviro variables and mean tree growth 
RGR.plot = merge(RGR.tree,B11plots,by="PlotID")
AGR.plot = merge(AGR.tree,B11plots,by="PlotID")

# merge tree growth and plot info 
RGR.tree.plot = merge(RGR.tree,B11plots,by="PlotID")
AGR.tree.plot = merge(AGR.tree,B11plots,by="PlotID")
#Mort.tree.plot = merge(Mort.tree,B11plots,by="PlotID")

# merge with tree size data 
RGR.tree.plot = merge(RGR.tree.plot,Size.tree,by="TreeID")
AGR.tree.plot = merge(AGR.tree.plot,Size.tree,by="TreeID")

# merge tree growth and tree diversity indices 
RGR.tree.div.2015 = merge(RGR.tree.plot,div.2015,by="PlotID")
RGR.tree.div.2016 = merge(RGR.tree.plot,div.2016,by="PlotID")
RGR.tree.div.2017 = merge(RGR.tree.plot,div.2017,by="PlotID")
RGR.tree.div.2018 = merge(RGR.tree.plot,div.2018,by="PlotID")

### for neighborhood analysis #############################

# merge competition indices and distances to oil palm at tree level 
neighborhood.2015.utm = merge(neighborhood.2015,tr.utm,by.x = "TreeID",by.y = "Tree_ID")
neighborhood.2016.utm = merge(neighborhood.2016,tr.utm,by.x = "TreeID",by.y = "Tree_ID")
neighborhood.2017.utm = merge(neighborhood.2017,tr.utm,by.x = "TreeID",by.y = "Tree_ID")

# merge with tree growth data 
RGR.neighborhood.2015 = merge(neighborhood.2015.utm,RGR.tree,by.x = "TreeID",by.y = "TreeID")
RGR.neighborhood.2016 = merge(neighborhood.2016.utm,RGR.tree,by.x = "TreeID",by.y = "TreeID")
RGR.neighborhood.2017 = merge(neighborhood.2017.utm,RGR.tree,by.x = "TreeID",by.y = "TreeID")
AGR.neighborhood.2015 = merge(neighborhood.2015.utm,AGR.tree,by.x = "TreeID",by.y = "TreeID")
AGR.neighborhood.2016 = merge(neighborhood.2016.utm,AGR.tree,by.x = "TreeID",by.y = "TreeID")
AGR.neighborhood.2017 = merge(neighborhood.2017.utm,AGR.tree,by.x = "TreeID",by.y = "TreeID")

# merge with Plot info 
RGR.neighborhood.2015 = merge(RGR.neighborhood.2015 , infoplots, by="PlotID")
RGR.neighborhood.2016 = merge(RGR.neighborhood.2016 , infoplots, by="PlotID")
RGR.neighborhood.2017 = merge(RGR.neighborhood.2017 , infoplots, by="PlotID")

AGR.neighborhood.2015 = merge(AGR.neighborhood.2015 , infoplots, by="PlotID")
AGR.neighborhood.2016 = merge(AGR.neighborhood.2016 , infoplots, by="PlotID")
AGR.neighborhood.2017 = merge(AGR.neighborhood.2017 , infoplots, by="PlotID")

# merge with tree size data 
AGR.neighborhood.2015 <- merge (AGR.neighborhood.2015, Size.tree, by="TreeID") 
AGR.neighborhood.2016 <- merge (AGR.neighborhood.2016, Size.tree, by="TreeID") 
AGR.neighborhood.2017 <- merge (AGR.neighborhood.2017, Size.tree, by="TreeID") 

RGR.neighborhood.2015 <- merge (RGR.neighborhood.2015, Size.tree, by="TreeID") 
RGR.neighborhood.2016 <- merge (RGR.neighborhood.2016, Size.tree, by="TreeID") 
RGR.neighborhood.2017 <- merge (RGR.neighborhood.2017, Size.tree, by="TreeID") 

## tree mortality  - at tree level ###################
# merge with tree mortality data 
#Mort.neighborhood.2015 = merge(neighborhood.2015.utm,Mort.tree,by.x = "TreeID",by.y = "TreeID")
#Mort.neighborhood.2016 = merge(neighborhood.2016.utm,Mort.tree,by.x = "TreeID",by.y = "TreeID")
#Mort.neighborhood.2017 = merge(neighborhood.2017.utm,Mort.tree,by.x = "TreeID",by.y = "TreeID")

# merge with Plot info 
#Mort.neighborhood.2015 = merge(Mort.neighborhood.2015 , infoplots, by="PlotID")
#Mort.neighborhood.2016 = merge(Mort.neighborhood.2016 , infoplots, by="PlotID")
#Mort.neighborhood.2017 = merge(Mort.neighborhood.2017 , infoplots, by="PlotID")


#####################################################################################
# -- multi-comparision tests 

#-- Kruskal-Wallis-Test
ind = which(is.finite(RGR.tree$Diam_inc_15.18))
kruskal.test(RGR.tree$Diam_inc_15.18[ind], RGR.tree$Species[ind])
#kruskal.test(RGR.tree$BA_inc_15.18[ind], RGR.tree$Species[ind])
#kruskal.test(RGR.tree$Height_15.18[ind], RGR.tree$Species[ind])

# -- pairwise comparition with wilcox test 
spec <- pairwise.wilcox.test(RGR.tree$Diam_inc_15.18, RGR.tree$Species,p.adj="bonf")

spec <- pairwise.wilcox.test(RGR.tree$BA_inc_15.18, RGR.tree$Species,p.adj="bonf")
round(as.data.frame(spec$p.value),digits=5)

# ALTERNATIVE 
# -- fit a simple one-way ANOVA model to the data 
tree.aov <- aov(Height_vertical.2017 ~ Species, data = RGR.tree) 
tree.aov <- aov(BA.2018 ~ Species, data = RGR.tree) 

tree.aov <- aov(Height_inc_15.18 ~ Species, data = RGR.tree) 
tree.aov <- aov(BA_inc_15.18 ~ Species, data = RGR.tree) 
tree.aov <- aov(Diam_inc_15.18 ~ Species, data = RGR.tree) 
tree.aov <- aov(surv.2018 ~ Species, data = survival.plots) 

#tree.aov <- aov(surv.2018 ~ Species, data = survival.DivLev.Size) 

# -- Apply the (single-step) Tukey test using the glht function in multcomp and sandiwch function for heteroscedasticity
summary(glht(tree.aov, linfct = mcp(Species  = "Tukey"),vcov = sandwich)) 

# -- for tree performance per diversity level 
for (sp in unique(survival.plots$Species)){
  print(sp)
  # -- survival rates 
  #tree.aov <- aov(surv.2018 ~ Div, data = survival.plots[Species==sp]) 
  #print (summary(glht(tree.aov, linfct = mcp(Div  = "Tukey"),vcov = sandwich))) 
  # -- growth rates 
  tree.aov <- aov(Diam_inc_15.18 ~ Div, data = RGR.plot[Species==sp]) 
  print (summary(glht(tree.aov, linfct = mcp(Div  = "Tukey"),vcov = sandwich))) 
  
}

######################################################################################
# Build a model for neighborhood analysis 

############################################################################
############################################################################
# -- Model 0: effect of plots-specific variables 

## mortality at plot level 

# all variables combined 
mod0 = lmer(surv.2018 ~ log(slope+1) + log(altitude+1) + log(gap+1)+ PC1 + PC2 + (1|Species), 
          data = survival.plots); car::Anova(mod0)

mod0 = lm(surv.2018 ~ scale(slope) + scale(altitude) + scale(gap)+ PC1 + PC2, 
            data = survival.plots); car::Anova(mod0)

# each variable separately 
# in mixed model 
mod0 = lmer(surv.2018 ~ slope+  (slope|Species), data = survival.plots); car::Anova(mod0)
mod0 = lmer(surv.2018 ~ altitude+ (altitude|Species), data = survival.plots); car::Anova(mod0) # singular fit 
mod0 = lmer(surv.2018 ~ gap + (gap|Species), data = survival.plots); car::Anova(mod0)
mod0 = lmer(surv.2018 ~ C+ (C|Species), data = survival.plots); car::Anova(mod0) # singular fit 
mod0 = lmer(surv.2018 ~ PH+ (PH|Species), data = survival.plots); car::Anova(mod0) 
mod0 = lmer(surv.2018 ~ clay + (clay|Species), data = survival.plots); car::Anova(mod0)
mod0 = lmer(surv.2018 ~ sand + (sand|Species), data = survival.plots); car::Anova(mod0)
mod0 = lmer(surv.2018 ~ silk + (silk|Species), data = survival.plots); car::Anova(mod0)
mod0 = lmer(surv.2018 ~ density + (density|Species), data = survival.plots); car::Anova(mod0) # singular fit 
mod0 = lmer(surv.2018 ~ bare + (bare|Species), data = survival.plots); car::Anova(mod0) # singular fit 
mod0 = lmer(surv.2018 ~ dens.ini + (dens.ini|Species), data = survival.plots); car::Anova(mod0) # singular fit 

# vizualize model output
x11(3,3)
ggplot(survival.plots, aes(gap,surv.2018,group = Species, col=Species))+
  geom_point() + 
  geom_line(aes(y=predict(mod0), group=Species, show.legend =FALSE))

## relative growth rates at tree level 

mod0 = lmer(log(Height_inc_15.18+1) ~ slope+  (slope|Species), data = RGR.tree.plot); car::Anova(mod0)
mod0 = lmer(log(Height_inc_15.18+1) ~ scale(altitude)+ (scale(altitude)|Species), data = RGR.tree.plot); car::Anova(mod0) # singular fit 
mod0 = lmer(log(Height_inc_15.18+1) ~ gap+ (gap|Species), data = RGR.tree.plot); car::Anova(mod0)
mod0 = lmer(log(Height_inc_15.18+1) ~ C+ (C|Species), data = RGR.tree.plot); car::Anova(mod0) # singular fit 
mod0 = lmer(log(Height_inc_15.18+1) ~ PH+ (PH|Species), data = RGR.tree.plot); car::Anova(mod0) 
mod0 = lmer(log(Height_inc_15.18+1) ~ clay + (clay|Species), data = RGR.tree.plot); car::Anova(mod0)
mod0 = lmer(log(Height_inc_15.18+1) ~ sand + (sand|Species), data = RGR.tree.plot); car::Anova(mod0)
mod0 = lmer(log(Height_inc_15.18+1) ~ silk + (silk|Species), data = RGR.tree.plot); car::Anova(mod0)
mod0 = lmer(log(Height_inc_15.18+1) ~ density + (density|Species), data = RGR.tree.plot); car::Anova(mod0) # singular fit 
#mod0 = lmer(log(Height_inc_15.18+1) ~ bare + (bare|Species), data = RGR.tree.plot); car::Anova(mod0) # singular fit 

x11(3,3)
ggplot(RGR.tree.plot[is.finite(log(Height_inc_15.18+1))], aes(gap,log(Height_inc_15.18+1),
  group = Species, col=Species))+  geom_point() + 
  geom_line(aes(y=predict(mod0), group=Species, show.legend =FALSE))


## get the effect of experimental treatement: diversity level and plot size at plot level 
# mod0.y1 <- lmer(log(Diam_inc_15.16+1) ~ (R + log(Size)) + (1| Species) + (1|PlotID),
#                 data = RGR.tree.div.2015 ,  weight=PlotID); car::Anova(mod0.y1)
# mod0.y2 <- lmer(log(Diam_inc_16.17+1) ~ (R + log(Size)) + (1| Species) + (1|PlotID),
#                 data = RGR.tree.div.2016 ,  weight=PlotID); car::Anova(mod0.y2)
# mod0.y3 <- lmer(log(Diam_inc_17.18+1) ~ (R + log(Size)) + (1| Species) + (1|PlotID),
#                 data = RGR.tree.div.2017, weight=PlotID ); car::Anova(mod0.y3)

## environmnetal variables and their interactions with the experimental treatement
# for the entire period

# exemple: sand
mod0.v1 <- lmer(log(Height_inc_15.18+1) ~ (log(sand+1) * (R ) + (1| Species) + (1|PlotID)),
                   data = RGR.tree.div.2015); car::Anova(mod0.v1)

# slope
mod0.v2 <- update(mod0.v1, . ~ . - log(sand+1) * (R) + log(slope+1) * (R )); car::Anova(mod0.v2)
# elevation
mod0.v3 <- update(mod0.v1, . ~ . - log(sand+1) * (R ) + log(altitude+1) * (R )); car::Anova(mod0.v3)
# soil PH
mod0.v4 <- update(mod0.v1, . ~ . - log(sand+1) * (R ) + log(PH+1) * (R )); car::Anova(mod0.v4)
# soil density
mod0.v5 <- update(mod0.v1, . ~ . - log(sand+1) * (R ) + log(density+1) * (R )); car::Anova(mod0.v5)
# soil C content
mod0.v6 <- update(mod0.v1, . ~ . - log(sand+1) * (R ) + log(C+1) * (R )); car::Anova(mod0.v6)
# soil texture: silk
mod0.v7 <- update(mod0.v1, . ~ . - log(sand+1) * (R ) + log(silk+1) * (R )); car::Anova(mod0.v7)
# soil texture: clay
mod0.v8 <- update(mod0.v1, . ~ . - log(sand+1) * (R ) + log(clay+1) * (R )); car::Anova(mod0.v8)
# gap fraction
mod0.v9 <- update(mod0.v1, . ~ . - log(sand+1) * (R ) + log(gap+1) * (R )); car::Anova(mod0.v9)
# bare soil
mod0.v10 <- update(mod0.v1, . ~ . - log(sand+1) * (R ) + log(bare+1) * (R )); car::Anova(mod0.v10)

x11()
dwplot(list(mod0.v1,mod0.v2,mod0.v3,mod0.v4,mod0.v5,mod0.v6,mod0.v7,mod0.v8,mod0.v9),effects="fixed")+
  geom_vline(xintercept=0,linetype=2)


# for each year individually
mod0.v1.y1 <- lmer(log(Diam_inc_15.16+1) ~ (log(dens.2015+1) * (R ) + (1| Species) + (1|PlotID)),
             data = RGR.tree.div.2015); car::Anova(mod0.v1.y1)
mod0.v1.y2 <- lmer(log(Diam_inc_16.17+1) ~ (log(dens.2016+1) * (R ) + (1| Species) + (1|PlotID)),
                data = RGR.tree.div.2016); car::Anova(mod0.v1.y2)
mod0.v1.y3 <- lmer(log(Diam_inc_17.18+1) ~ (log(dens.2017+1)* (R ) + (1| Species) + (1|PlotID)),
                data = RGR.tree.div.2017); car::Anova(mod0.v1.y3)

 x11(5,2)
 dwplot(list(mod0.v1.y1,mod0.v1.y2,mod0.v1.y3),effects="fixed")+
  geom_vline(xintercept=0,linetype=2)

# # slope
# mod0.v2.y1 <- update(mod0.v1.y1, . ~ . - log(sand+1) * (R + log(Size)) + log(slope+1) * (R + log(Size))); car::Anova(mod0.v2.y1)
# mod0.v2.y2 <- update(mod0.v1.y2, . ~ . - log(sand+1) * (R + log(Size)) + log(slope+1) * (R + log(Size))); car::Anova(mod0.v2.y2)
# mod0.v2.y3 <- update(mod0.v1.y3, . ~ . - log(sand+1) * (R + log(Size)) + log(slope+1) * (R + log(Size))); car::Anova(mod0.v2.y3)
# # elevation
# mod0.v2.y1 <- update(mod0.v1.y1, . ~ . - log(sand+1) * (R + log(Size)) + log(altitude+1) * (R + log(Size))); car::Anova(mod0.v2.y1)
# mod0.v2.y2 <- update(mod0.v1.y2, . ~ . - log(sand+1) * (R + log(Size)) + log(altitude+1) * (R + log(Size))); car::Anova(mod0.v2.y2)
# mod0.v2.y3 <- update(mod0.v1.y3, . ~ . - log(sand+1) * (R + log(Size)) + log(altitude+1) * (R + log(Size))); car::Anova(mod0.v2.y3)
# # soil PH
# mod0.v2.y1 <- update(mod0.v1.y1, . ~ . - log(sand+1) * (R + log(Size)) + log(PH+1) * (R + log(Size))); car::Anova(mod0.v2.y1)
# mod0.v2.y2 <- update(mod0.v1.y2, . ~ . - log(sand+1) * (R + log(Size)) + log(PH+1) * (R + log(Size))); car::Anova(mod0.v2.y2)
# mod0.v2.y3 <- update(mod0.v1.y3, . ~ . - log(sand+1) * (R + log(Size)) + log(PH+1) * (R + log(Size))); car::Anova(mod0.v2.y3)
# # soil density
# mod0.v2.y1 <- update(mod0.v1.y1, . ~ . - log(sand+1) * (R + log(Size)) + log(density+1) * (R + log(Size))); car::Anova(mod0.v2.y1)
# mod0.v2.y2 <- update(mod0.v1.y2, . ~ . - log(sand+1) * (R + log(Size)) + log(density+1) * (R + log(Size))); car::Anova(mod0.v2.y2)
# mod0.v2.y3 <- update(mod0.v1.y3, . ~ . - log(sand+1) * (R + log(Size)) + log(density+1) * (R + log(Size))); car::Anova(mod0.v2.y3)
# # soil C content
# mod0.v2.y1 <- update(mod0.v1.y1, . ~ . - log(sand+1) * (R + log(Size)) + log(C+1) * (R + log(Size))); car::Anova(mod0.v2.y1)
# mod0.v2.y2 <- update(mod0.v1.y2, . ~ . - log(sand+1) * (R + log(Size)) + log(C+1) * (R + log(Size))); car::Anova(mod0.v2.y2)
# mod0.v2.y3 <- update(mod0.v1.y3, . ~ . - log(sand+1) * (R + log(Size)) + log(C+1) * (R + log(Size))); car::Anova(mod0.v2.y3)
# # soil texture: silk
# mod0.v2.y1 <- update(mod0.v1.y1, . ~ . - log(sand+1) * (R + log(Size)) + log(silk+1) * (R + log(Size))); car::Anova(mod0.v2.y1)
# mod0.v2.y2 <- update(mod0.v1.y2, . ~ . - log(sand+1) * (R + log(Size)) + log(silk+1) * (R + log(Size))); car::Anova(mod0.v2.y2)
# mod0.v2.y3 <- update(mod0.v1.y3, . ~ . - log(sand+1) * (R + log(Size)) + log(silk+1) * (R + log(Size))); car::Anova(mod0.v2.y3)
# # soil texture: clay
# mod0.v2.y1 <- update(mod0.v1.y1, . ~ . - log(sand+1) * (R + log(Size)) + log(clay+1) * (R + log(Size))); car::Anova(mod0.v2.y1)
# mod0.v2.y2 <- update(mod0.v1.y2, . ~ . - log(sand+1) * (R + log(Size)) + log(clay+1) * (R + log(Size))); car::Anova(mod0.v2.y2)
# mod0.v2.y3 <- update(mod0.v1.y3, . ~ . - log(sand+1) * (R + log(Size)) + log(clay+1) * (R + log(Size))); car::Anova(mod0.v2.y3)
# # gap fraction
# mod0.v2.y1 <- update(mod0.v1.y1, . ~ . - log(sand+1) * (R + log(Size)) + log(gap+1) * (R + log(Size))); car::Anova(mod0.v2.y1)
# mod0.v2.y2 <- update(mod0.v1.y2, . ~ . - log(sand+1) * (R + log(Size)) + log(gap+1) * (R + log(Size))); car::Anova(mod0.v2.y2)
# mod0.v2.y3 <- update(mod0.v1.y3, . ~ . - log(sand+1) * (R + log(Size)) + log(gap+1) * (R + log(Size))); car::Anova(mod0.v2.y3)
# # bare soil
# mod0.v2.y1 <- update(mod0.v1.y1, . ~ . - log(sand+1) * (R + log(Size)) + log(bare+1) * (R + log(Size))); car::Anova(mod0.v2.y1)
# mod0.v2.y2 <- update(mod0.v1.y2, . ~ . - log(sand+1) * (R + log(Size)) + log(bare+1) * (R + log(Size))); car::Anova(mod0.v2.y2)
# mod0.v2.y3 <- update(mod0.v1.y3, . ~ . - log(sand+1) * (R + log(Size)) + log(bare+1) * (R + log(Size))); car::Anova(mod0.v2.y3)
# 
# x11(5,2)
# dwplot(list(mod0.v2.y1,mod0.v2.y2,mod0.v2.y3),effects="fixed")+
#   geom_vline(xintercept=0,linetype=2)

# tree density over time and with tree diversity 
mod0.v2.y1 <- update(mod0.v1.y1, . ~ . - log(sand+1) * (R ) + log(dens.2015+1) * (R)); car::Anova(mod0.v2.y1)
mod0.v2.y2 <- update(mod0.v1.y2, . ~ . - log(sand+1) * (R ) + log(dens.2016+1) * (R)); car::Anova(mod0.v2.y2)
mod0.v2.y3 <- update(mod0.v1.y3, . ~ . - log(sand+1) * (R ) + log(dens.2017+1) * (R)); car::Anova(mod0.v2.y3)

x11(5,2)
dwplot(mod0.v2.y1,effects="fixed")+
  geom_vline(xintercept=0,linetype=2)




############################################################################
############################################################################
# -- neighborhood analyses 

############################################################################
## Model 1

# -- log-transform the data
mod1.y1 <- lmer(log(Diam_inc_15.16+1) ~ (log(dOPal+1) + log(dOPrem+1)  + log(dEdge+1) + log(all+1) + log(Size) 
                                           + log(Diameter.2015) + (1|Species) + (1|PlotID)),
             data = AGR.neighborhood.2015)

mod1.y2<- lmer(log(Diam_inc_16.17+1) ~ (log(dOPal+1) + log(dOPrem+1)  + log(dEdge+1) + log(all+1) + log(Size) 
                                          + log(Diameter.2016)+ (1|Species) + (1|PlotID)),
               data = AGR.neighborhood.2016)

mod1.y3 <- lmer(log(Diam_inc_17.18+1) ~ (log(dOPal+1) + log(dOPrem+1)  + log(dEdge+1) + log(all+1) + log(Size) 
                                           + log(Diameter.2017)+ (1|Species) + (1|PlotID)),
             data = AGR.neighborhood.2017)

# -- Z-tranform the data 
mod1.y1 <- lmer(scale(Diam_inc_15.16) ~ (scale(dOPal)+scale(dOPrem)+scale(dEdge)+ scale(all)+scale(Size)
                                           + scale(Diameter.2015) + (1|Species) + (1|PlotID)),
                data = AGR.neighborhood.2015)

mod1.y2<- lmer(scale(Diam_inc_16.17) ~ (scale(dOPal)+scale(dOPrem)+scale(dEdge)+ scale(all)+scale(Size)
                                          + scale(Diameter.2016)+ (1|Species) + (1|PlotID)),
               data = AGR.neighborhood.2016)

mod1.y3 <- lmer(scale(Diam_inc_17.18) ~ (scale(dOPal)+scale(dOPrem)+scale(dEdge)+ scale(all)+scale(Size)
                                           + scale(Diameter.2017)+ (1|Species) + (1|PlotID)),
                data = AGR.neighborhood.2017)

# -- check covariares effect separately
#mod1.y1 <- update(mod1.y1,. ~ . -(log(dOPrem+1) + log(all+1)  + log(dEdge+1) + log(Size) ))
#mod1.y2 <- update(mod1.y3,. ~ . -(log(dOPrem+1) + log(all+1)  + log(dEdge+1) + log(Size) ))
#mod1.y3 <- update(mod1.y3,. ~ . -(log(dOPrem+1) + log(all+1)  + log(dEdge+1) + log(Size) ))

# -- get relative growth rate model 
mod1.y1 <- update(mod1.y1,. ~ . - log(Diameter.2015),data = RGR.neighborhood.2015)
mod1.y2 <- update(mod1.y2,. ~ . - log(Diameter.2016),data = RGR.neighborhood.2016)
mod1.y3 <- update(mod1.y3,. ~ . - log(Diameter.2017),data = RGR.neighborhood.2017)


# vizualize model output
x11(7,3); dwplot(list(mod1.y1,mod1.y2,mod1.y3),effects="fixed")+
  geom_vline(xintercept=0,linetype=2)


## tree mortality (but problem with the model diagnosticated - bias, heteroscedasticity ... )
# mod1 <- glmer(Survival.2018 ~ (log(dOPal+1) + log(dOPrem+1)  + log(dEdge+1) + log(all+1) + log(Size) 
#                                + (1|PlotID)+ (1|Species)),
#               data = RGR.neighborhood.2015,  family = "binomial"); car::Anova(mod1)
# # per species 
# mod1_pet <- update(mod1,data= RGR.neighborhood.2015[Species=="petai"],. ~ . - (1|Species)); car::Anova(mod1_pet)
# mod1_sun <- update(mod1,data= RGR.neighborhood.2015[Species=="sungkai"],. ~ . - (1|Species)); car::Anova(mod1_sun)
# mod1_jeng <- update(mod1,data= RGR.neighborhood.2015[Species=="Jengkol"],. ~ . - (1|Species)); car::Anova(mod1_jeng)
# mod1_mer <- update(mod1,data= RGR.neighborhood.2015[Species=="meranti"],. ~ . - (1|Species));  car::Anova(mod1_mer)
# mod1_dur <- update(mod1,data= RGR.neighborhood.2015[Species=="durian"],. ~ . - (1|Species));  car::Anova(mod1_dur)
# mod1_jel <- update(mod1,data= RGR.neighborhood.2015[Species=="jelutung"],. ~ . - (1|Species)); car::Anova(mod1_jel)
# 
# x11()
# dwplot(list(mod1_jel,mod1_dur,mod1_mer,mod1_pet,mod1_jeng,mod1_sun,mod1),effects="fixed",dodge_size = 0.8)+
#   geom_vline(xintercept=0,linetype=2)


############################################################################
# -- Model 2 : add effect of diversity 

mod2.y1 <- update(mod1.y1, . ~ . + R_neighbors )
mod2.y2 <- update(mod1.y2, . ~ . + R_neighbors)
mod2.y3 <- update(mod1.y3, . ~ . + R_neighbors)

x11(8,3); dwplot(list(mod2.y1,mod2.y2,mod2.y3),effects="fixed")+
  geom_vline(xintercept=0,linetype=2)

############################################################################
# -- Model 3 : add effect of con- and heter-specific competition

mod3.y1 <- update(mod1.y1, . ~ . -  log(all+1)+ log(heterosp+1) +  log(consp+1) )
mod3.y2 <- update(mod1.y2, . ~ . -  log(all+1)+ log(heterosp+1)+  log(consp+1) )
mod3.y3 <- update(mod1.y3, . ~ . -  log(all+1)+ log(heterosp+1)+  log(consp+1) )

x11(8,3); dwplot(list(mod3.y1,mod3.y2,mod3.y3),effects="fixed")+
  geom_vline(xintercept=0,linetype=2)


############################################################################
# -- Model 4 : effect of species identity among the nighbors  

mod4.y3 <- update(mod1.y3,.~.-  log(all+1)
                  +log(petai+1)
                  +log(meranti+1)
                  +log(durian+1)
                  +log(jelutung+1)
                  +log(Jengkol+1)
                  +log(sungkai+1))

mod4.y2 <- update(mod1.y2,.~.-  log(all+1)
                  +log(petai+1)
                  +log(meranti+1)
                  +log(durian+1)
                  +log(jelutung+1)
                  +log(Jengkol+1)
                  +log(sungkai+1))

mod4.y1 <- update(mod1.y1,.~.-  log(all+1)
                  +log(petai+1)
                  +log(meranti+1)
                  +log(durian+1)
                  +log(jelutung+1)
                  +log(Jengkol+1)
                  +log(sungkai+1))

x11(); dwplot(list(mod4.y1,mod4.y2,mod4.y3),effects="fixed")+
  geom_vline(xintercept=0,linetype=2)


############################################################################
############################################################################
## Model diagnostic 

# model diagnostic
plot(mod0)
cor(RGR.neighborhood.2015$Survival.2018,predict(mod1, type="response"))

# Diagnostics: residual scale
## fitted vs resid
plot(mod0,type=c("p","smooth"))
## scale-location
plot(mod0,sqrt(abs(resid(.)))~fitted(.),type=c("p","smooth"))
plot(mod0,sqrt(abs(resid(.)))~PlotID,type=c("p","smooth"))
plot(mod,sqrt(abs(resid(.)))~as.numeric(Species),type=c("p","smooth"))
plot(mod,sqrt(abs(resid(.)))~TreeID,type=c("p","smooth"))
plot(mod,sqrt(abs(resid(.)))~log(all+1),type=c("p","smooth"))
plot(mod,sqrt(abs(resid(.)))~log(dOPal+1),type=c("p","smooth"))
plot(mod,sqrt(abs(resid(.)))~log(D2015+1),type=c("p","smooth"))

## q-q
lattice::qqmath(mod0)

car::Anova(mod)
afex::anova

# degree freedom
library(lmerTest)
summary(as_lmerModLmerTest(mod2_sun)) # Satterthwaite's method by default 
summary(as_lmerModLmerTest(mod),ddf="Kenward-Roger")

#summary(mod)
#anova(mod)
allFit(mod1)
rePCA(mod)


############################################################################
############################################################################

